use super::{NPC, NPCSayInfo, NPCSayType};
use crate::models::item::Pronouns;

pub fn npc_list() -> Vec<NPC> {
    use NPCSayType::FromFixedList;
    let melbs_citizen_stdsay = NPCSayInfo {
        say_code: "babble",
        frequency_secs: 120,
        talk_type: FromFixedList(vec!(
            (false, "I'm so sick of being cloned."),
            (false, "I hope I don't die again today."),
            (false, "I wish the so-called king would do something about the damned zombies everywhere."),
            (true, "I earn so many credits making babies for the body factory - it literally pays my bills."),
            (false, "I know people hated the empire, but I kind of wish it was still intact - it was a lot better than what we have now."),
            (false, "I wish there wasn't so much radiation outside of Melbs CBD."),
            (false, "I heard about a guy who went to a special place somewhere around here, and there was a machine that enhanced his wristpad and gave him basically superpowers."),
            (false, "The damn vampire movement... they are all so sneaky, and I never know when they are going to come for my blood."),
        ))
    };
       
    macro_rules! citizen {
        ($code: expr, $name: expr, $spawn: expr, $pronouns: expr) => {
            NPC {
                code: concat!("melbs_citizen_", $code),
                name: $name,
                pronouns: $pronouns,
                description: "A fairly ordinary looking citizen of Melbs, clearly weary from the harst reality of post-apocalyptic life",
                spawn_location: concat!("room/melbs_", $spawn),
                message_handler: None,
                wander_zones: vec!("melbs"),
                says: vec!(melbs_citizen_stdsay.clone()),
                ..Default::default()
            }
        }
    }

    vec!(
      citizen!("1", "Matthew Thomas", "kingst_latrobest", Pronouns::default_male()),
      citizen!("2", "Matthew Perez", "kingst_20", Pronouns::default_male()),
      citizen!("3", "Kimberly Jackson", "kingst_40", Pronouns::default_female()),
      citizen!("4", "Michael Sanchez", "kingst_50", Pronouns::default_male()),
      citizen!("5", "Jessica Davis", "kingst_bourkest", Pronouns::default_female()),
      citizen!("6", "Robert Davis", "kingst_70", Pronouns::default_male()),
      citizen!("7", "Paul Lewis", "kingst_90", Pronouns::default_male()),
      citizen!("8", "Andrew Moore", "kingst_collinsst", Pronouns::default_male()),
      citizen!("9", "Betty Thomas", "kingst_100", Pronouns::default_female()),
      citizen!("10", "Mary Robinson", "kingst_110", Pronouns::default_female()),
      citizen!("11", "Lisa Lopez", "kingst_flinderst", Pronouns::default_female()),
      citizen!("12", "Kimberly Martinez", "flindersst_200", Pronouns::default_female()),
      citizen!("13", "Anthony Nguyen", "flindersst_190", Pronouns::default_male()),
      citizen!("14", "Joshua Green", "flindersst_180", Pronouns::default_male()),
      citizen!("15", "Emily Wright", "flindersst_170", Pronouns::default_female()),
      citizen!("16", "Ashley Thomas", "lonsdalest_130", Pronouns::default_male()),
      citizen!("17", "Jessica Miller", "kingst_80", Pronouns::default_female()),
      citizen!("18", "Anthony Lopez", "lonsdalest_140", Pronouns::default_male()),
      citizen!("19", "John Lopez", "elizabethst_lonsdalest", Pronouns::default_male()),
      citizen!("20", "Thomas Garcia", "williamsst_120", Pronouns::default_male()),
      citizen!("21", "Donna Thompson", "elizabethst_60", Pronouns::default_female()),
      citizen!("22", "Matthew Davis", "williamsst_100", Pronouns::default_male()),
      citizen!("23", "Steven Jones", "swanstonst_120", Pronouns::default_male()),
      citizen!("24", "Linda Smith", "swanstonst_lonsdalest", Pronouns::default_male()),
      citizen!("25", "Karen Rodriguez", "bourkest_180", Pronouns::default_female()),
      citizen!("26", "Paul Scott", "swanstonst_70", Pronouns::default_male()),
      citizen!("27", "Ashley Thomas", "lonsdalest_130", Pronouns::default_male()),
      citizen!("28", "Sandra Scott", "elizabethst_30", Pronouns::default_female()),
      citizen!("29", "Michael Rodriguez", "swanstonst_70", Pronouns::default_male()),
      citizen!("30", "Donald Miller", "elizabethst_30", Pronouns::default_male()),
      citizen!("31", "Charles Moore", "lonsdalest_160", Pronouns::default_male()),
      citizen!("32", "Ashley Sanchez", "kingst_100", Pronouns::default_male()),
      citizen!("33", "Margaret Lewis", "flindersst_180", Pronouns::default_female()),
      citizen!("34", "Sandra Thompson", "swanstonst_80", Pronouns::default_female()),
      citizen!("35", "Sandra King", "lonsdalest_150", Pronouns::default_female()),
      citizen!("36", "Lisa Anderson", "lonsdalest_210", Pronouns::default_female()),
      citizen!("37", "Kimberly Martin", "kingst_80", Pronouns::default_female()),
      citizen!("38", "Susan Smith", "latrobest_190", Pronouns::default_female()),
      citizen!("39", "Susan Martin", "collinsst_150", Pronouns::default_female()),
      citizen!("40", "Linda Scott", "williamsst_30", Pronouns::default_female()),
      citizen!("41", "Donald Miller", "elizabethst_80", Pronouns::default_male()),
      citizen!("42", "Mark Hill", "collinsst_120", Pronouns::default_male()),
      citizen!("43", "William Perez", "queenst_90", Pronouns::default_male()),
      citizen!("44", "Donald Perez", "queenst_lonsdalest", Pronouns::default_male()),
      citizen!("45", "Lisa Rodriguez", "collinsst_100", Pronouns::default_female()),
      citizen!("46", "James Adams", "latrobest_150", Pronouns::default_male()),
      citizen!("47", "James Moore", "latrobest_130", Pronouns::default_male()),
      citizen!("48", "Joseph Martin", "bourkest_150", Pronouns::default_male()),
      citizen!("49", "Matthew Jones", "kingst_60", Pronouns::default_male()),
      citizen!("50", "Michael Sanchez", "queenst_100", Pronouns::default_male()),
      citizen!("51", "Donna Torres", "flindersst_150", Pronouns::default_female()),
      citizen!("52", "Barbara Garcia", "swanstonst_50", Pronouns::default_female()),
      citizen!("53", "Daniel Miller", "bourkest_110", Pronouns::default_male()),
      citizen!("54", "Robert Young", "kingst_collinsst", Pronouns::default_male()),
      citizen!("55", "Donald Flores", "swanstonst_40", Pronouns::default_male()),
      citizen!("56", "Charles Thomas", "flindersst_110", Pronouns::default_male()),
      citizen!("57", "William Torres", "swanstonst_60", Pronouns::default_male()),
      citizen!("58", "Barbara Gonzalez", "collinsst_190", Pronouns::default_female()),
      citizen!("59", "Mary Smith", "bourkest_180", Pronouns::default_female()),
      citizen!("60", "Michael John", "williamsst_110", Pronouns::default_male()),
    )
}
